encode_copy_format

Function encode_copy_format 

pub fn encode_copy_format<'a>(
    params: &CopyFormatParams<'a>,
    row: &RowRef,
    typ: &SqlRelationType,
    out: &mut Vec<u8>,
    settings: TextEncodeSettings,
) -> Result<(), Error>
Encodes the given Row into bytes based on the given CopyFormatParams.

settings affects only the text and CSV formats. Callers that do not encode on behalf of a session, such as COPY TO <external destination>, which is executed in the dataflow layer, must pass TextEncodeSettings::STABLE.